<?php
class NotificationService {
    private $db;
    private $webSocketServer;
    
    public function __construct($db) {
        $this->db = $db;
        // إعداد خادم WebSocket
        $this->webSocketServer = new WebSocketServer();
    }
    
    public function sendNotification($userId, $notification) {
        try {
            // حفظ الإشعار في قاعدة البيانات
            $stmt = $this->db->prepare("
                INSERT INTO notifications (
                    user_id, type, title, message, link, created_at
                ) VALUES (
                    :user_id, :type, :title, :message, :link, NOW()
                )
            ");
            
            $stmt->execute([
                ':user_id' => $userId,
                ':type' => $notification['type'],
                ':title' => $notification['title'],
                ':message' => $notification['message'],
                ':link' => $notification['link'] ?? null
            ]);
            
            // إرسال الإشعار عبر WebSocket
            $this->webSocketServer->broadcast(json_encode([
                'type' => 'notification',
                'data' => $notification
            ]));
            
            // إرسال إشعار بريد إلكتروني إذا كان مفعلاً
            $this->sendEmailNotification($userId, $notification);
            
            return true;
        } catch (Exception $e) {
            error_log("Notification Error: " . $e->getMessage());
            return false;
        }
    }
    
    private function sendEmailNotification($userId, $notification) {
        // التحقق من إعدادات المستخدم
        $stmt = $this->db->prepare("
            SELECT email, email_notifications 
            FROM users 
            WHERE id = :user_id
        ");
        $stmt->execute([':user_id' => $userId]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($user && $user['email_notifications']) {
            // إرسال البريد الإلكتروني
            $to = $user['email'];
            $subject = $notification['title'];
            $message = $notification['message'];
            
            $headers = 'From: نظام المقاولات <no-reply@your-domain.com>' . "\r\n";
            $headers .= 'Content-Type: text/html; charset=UTF-8' . "\r\n";
            
            mail($to, $subject, $message, $headers);
        }
    }
    
    public function getUnreadCount($userId) {
        $stmt = $this->db->prepare("
            SELECT COUNT(*) as count 
            FROM notifications 
            WHERE user_id = :user_id AND read = 0
        ");
        $stmt->execute([':user_id' => $userId]);
        $result = $stmt->fetch(PDO::FETCH_ASSOC);
        
        return $result['count'];
    }
    
    public function markAsRead($notificationId, $userId) {
        $stmt = $this->db->prepare("
            UPDATE notifications 
            SET read = 1 
            WHERE id = :id AND user_id = :user_id
        ");
        return $stmt->execute([
            ':id' => $notificationId,
            ':user_id' => $userId
        ]);
    }
    
    public function markAllAsRead($userId) {
        $stmt = $this->db->prepare("
            UPDATE notifications 
            SET read = 1 
            WHERE user_id = :user_id AND read = 0
        ");
        return $stmt->execute([':user_id' => $userId]);
    }
}