<?php
session_start();
require_once 'config.php';

// التحقق من صلاحيات المستخدم (يجب أن يكون مدير)
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: login.php");
    exit();
}
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة النسخ الاحتياطي - نظام المقاولات</title>
    <link rel="stylesheet" href="css/style.css">
    <link rel="stylesheet" href="css/backup.css">
</head>
<body>
    <div class="dashboard-container">
        <?php include 'includes/sidebar.php'; ?>
        
        <main class="main-content">
            <div class="header">
                <h1>إدارة النسخ الاحتياطي</h1>
            </div>

            <!-- ملخص حالة النسخ الاحتياطي -->
            <div class="backup-status">
                <div class="status-card">
                    <h3>آخر نسخة احتياطية</h3>
                    <p id="lastBackupDate">جاري التحميل...</p>
                </div>
                <div class="status-card">
                    <h3>حجم قاعدة البيانات</h3>
                    <p id="databaseSize">جاري التحميل...</p>
                </div>
                <div class="status-card">
                    <h3>حالة النسخ التلقائي</h3>
                    <p id="autoBackupStatus">جاري التحميل...</p>
                </div>
            </div>

            <!-- أزرار التحكم -->
            <div class="control-buttons">
                <button id="createBackup" class="btn primary-btn">
                    إنشاء نسخة احتياطية جديدة
                </button>
                <button id="restoreBackup" class="btn warning-btn">
                    استعادة من نسخة احتياطية
                </button>
                <button id="downloadBackup" class="btn success-btn">
                    تحميل آخر نسخة احتياطية
                </button>
            </div>

            <!-- إعدادات النسخ الاحتياطي -->
            <div class="backup-settings">
                <h2>إعدادات النسخ الاحتياطي التلقائي</h2>
                <form id="backupSettingsForm">
                    <div class="form-group">
                        <label>تفعيل النسخ الاحتياطي التلقائي</label>
                        <label class="switch">
                            <input type="checkbox" id="autoBackupEnabled" name="autoBackupEnabled">
                            <span class="slider"></span>
                        </label>
                    </div>
                    <div class="form-group">
                        <label>تكرار النسخ الاحتياطي</label>
                        <select name="backupFrequency" id="backupFrequency">
                            <option value="daily">يومي</option>
                            <option value="weekly">أسبوعي</option>
                            <option value="monthly">شهري</option>
                        </select>
                    </div>
                    <div class="form-group">
                        <label>وقت النسخ الاحتياطي</label>
                        <input type="time" name="backupTime" id="backupTime">
                    </div>
                    <div class="form-group">
                        <label>الاحتفاظ بالنسخ لمدة</label>
                        <input type="number" name="retentionDays" id="retentionDays" min="1">
                        <span>يوم</span>
                    </div>
                    <button type="submit" class="btn primary-btn">حفظ الإعدادات</button>
                </form>
            </div>

            <!-- سجل النسخ الاحتياطي -->
            <div class="backup-history">
                <h2>سجل النسخ الاحتياطي</h2>
                <table>
                    <thead>
                        <tr>
                            <th>التاريخ</th>
                            <th>النوع</th>
                            <th>الحجم</th>
                            <th>الحالة</th>
                            <th>الإجراءات</th>
                        </tr>
                    </thead>
                    <tbody id="backupHistoryTable">
                        <!-- سيتم تعبئة البيانات عبر JavaScript -->
                    </tbody>
                </table>
            </div>
        </main>
    </div>

    <!-- نافذة استعادة النسخة الاحتياطية -->
    <div id="restoreModal" class="modal">
        <div class="modal-content">
            <span class="close">&times;</span>
            <h2>استعادة نسخة احتياطية</h2>
            <div class="warning-message">
                <p>تحذير: ستؤدي عملية الاستعادة إلى استبدال جميع البيانات الحالية بالبيانات من النسخة الاحتياطية المحددة.</p>
            </div>
            <form id="restoreForm">
                <div class="form-group">
                    <label>اختر النسخة الاحتياطية</label>
                    <select name="backupFile" id="backupFileSelect" required>
                        <!-- سيتم تعبئة الخيارات عبر JavaScript -->
                    </select>
                </div>
                <div class="form-group">
                    <label>كلمة المرور للتأكيد</label>
                    <input type="password" name="confirmPassword" required>
                </div>
                <button type="submit" class="btn warning-btn">تأكيد الاستعادة</button>
            </form>
        </div>
    </div>

    <script src="js/backup.js"></script>
</body>
</html>