<?php
require_once '../config.php';
require_once '../api/backup/backup_handler.php';

try {
    // التحقق من إعدادات النسخ الاحتياطي التلقائي
    $stmt = $db->query("SELECT * FROM backup_settings WHERE id = 1");
    $settings = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$settings['enabled']) {
        exit("النسخ الاحتياطي التلقائي غير مفعل");
    }
    
    // التحقق من جدول النسخ الاحتياطي
    $currentTime = date('H:i');
    $currentDay = date('N'); // 1 (الاثنين) حتى 7 (الأحد)
    
    $shouldBackup = false;
    switch ($settings['frequency']) {
        case 'daily':
            $shouldBackup = true;
            break;
        case 'weekly':
            $shouldBackup = ($currentDay == 1); // الاثنين
            break;
        case 'monthly':
            $shouldBackup = (date('j') == 1); // أول يوم في الشهر
            break;
    }
    
    if ($shouldBackup && $currentTime == $settings['time']) {
        $backupHandler = new BackupHandler($db);
        
        // إنشاء نسخة احتياطية
        if ($backupHandler->createBackup('auto')) {
            // تنظيف النسخ الاحتياطية القديمة
            $backupHandler->cleanOldBackups($settings['retention_days']);
            echo "تم إنشاء النسخة الاحتياطية بنجاح";
        } else {
            throw new Exception("فشل في إنشاء النسخة الاحتياطية");
        }
    }
} catch (Exception $e) {
    error_log("Auto Backup Error: " . $e->getMessage());
    echo "حدث خطأ: " . $e->getMessage();
}