<?php
session_start();
require_once 'config.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>المصروفات والإيرادات - نظام المقاولات</title>
    <link rel="stylesheet" href="css/style.css">
    <link rel="stylesheet" href="css/finances.css">
</head>
<body>
    <div class="dashboard-container">
        <?php include 'includes/sidebar.php'; ?>
        
        <main class="main-content">
            <!-- التبويبات -->
            <div class="tabs">
                <button class="tab-btn active" data-tab="expenses">المصروفات</button>
                <button class="tab-btn" data-tab="revenues">الإيرادات</button>
            </div>

            <!-- قسم المصروفات -->
            <div class="tab-content active" id="expenses-content">
                <div class="header">
                    <h2>المصروفات</h2>
                    <button class="add-btn" onclick="showAddExpenseModal()">إضافة مصروف</button>
                </div>

                <div class="filters">
                    <div class="filter-group">
                        <label>الفترة:</label>
                        <input type="date" id="expenseStartDate">
                        <span>إلى</span>
                        <input type="date" id="expenseEndDate">
                    </div>
                    <div class="filter-group">
                        <label>المشروع:</label>
                        <select id="expenseProjectFilter">
                            <option value="">جميع المشاريع</option>
                        </select>
                    </div>
                    <div class="filter-group">
                        <label>نوع المصروف:</label>
                        <select id="expenseTypeFilter">
                            <option value="">الكل</option>
                            <option value="cash">نقدي</option>
                            <option value="credit">آجل</option>
                        </select>
                    </div>
                </div>

                <div class="table-container">
                    <table id="expensesTable">
                        <thead>
                            <tr>
                                <th>التاريخ</th>
                                <th>المشروع</th>
                                <th>الوصف</th>
                                <th>المبلغ</th>
                                <th>النوع</th>
                                <th>الحالة</th>
                                <th>الإجراءات</th>
                            </tr>
                        </thead>
                        <tbody id="expensesTableBody"></tbody>
                        <tfoot>
                            <tr>
                                <td colspan="3">الإجمالي</td>
                                <td id="totalExpenses">0 ريال</td>
                                <td colspan="3"></td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>

            <!-- قسم الإيرادات -->
            <div class="tab-content" id="revenues-content">
                <div class="header">
                    <h2>الإيرادات</h2>
                    <button class="add-btn" onclick="showAddRevenueModal()">إضافة إيراد</button>
                </div>

                <div class="filters">
                    <div class="filter-group">
                        <label>الفترة:</label>
                        <input type="date" id="revenueStartDate">
                        <span>إلى</span>
                        <input type="date" id="revenueEndDate">
                    </div>
                    <div class="filter-group">
                        <label>المشروع:</label>
                        <select id="revenueProjectFilter">
                            <option value="">جميع المشاريع</option>
                        </select>
                    </div>
                    <div class="filter-group">
                        <label>طريقة الدفع:</label>
                        <select id="paymentMethodFilter">
                            <option value="">الكل</option>
                            <option value="cash">نقدي</option>
                            <option value="bank">بنك</option>
                            <option value="transfer">حوالة</option>
                        </select>
                    </div>
                </div>

                <div class="table-container">
                    <table id="revenuesTable">
                        <thead>
                            <tr>
                                <th>التاريخ</th>
                                <th>المشروع</th>
                                <th>الوصف</th>
                                <th>المبلغ</th>
                                <th>طريقة الدفع</th>
                                <th>الإجراءات</th>
                            </tr>
                        </thead>
                        <tbody id="revenuesTableBody"></tbody>
                        <tfoot>
                            <tr>
                                <td colspan="3">الإجمالي</td>
                                <td id="totalRevenues">0 ريال</td>
                                <td colspan="2"></td>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        </main>
    </div>

    <!-- نموذج إضافة مصروف -->
    <div id="addExpenseModal" class="modal">
        <div class="modal-content">
            <span class="close" onclick="closeModal('addExpenseModal')">&times;</span>
            <h2>إضافة مصروف جديد</h2>
            <form id="addExpenseForm">
                <div class="form-group">
                    <label>المشروع</label>
                    <select name="project_id" required>
                        <option value="">اختر المشروع</option>
                    </select>
                </div>
                <div class="form-group">
                    <label>التاريخ</label>
                    <input type="date" name="expense_date" required>
                </div>
                <div class="form-group">
                    <label>المبلغ</label>
                    <input type="number" name="amount" step="0.01" required>
                </div>
                <div class="form-group">
                    <label>نوع المصروف</label>
                    <select name="expense_type" required>
                        <option value="cash">نقدي</option>
                        <option value="credit">آجل</option>
                    </select>
                </div>
                <div class="form-group">
                    <label>الوصف</label>
                    <textarea name="description" rows="3"></textarea>
                </div>
                <button type="submit">إضافة المصروف</button>
            </form>
        </div>
    </div>

    <!-- نموذج إضافة إيراد -->
    <div id="addRevenueModal" class="modal">
        <div class="modal-content">
            <span class="close" onclick="closeModal('addRevenueModal')">&times;</span>
            <h2>إضافة إيراد جديد</h2>
            <form id="addRevenueForm">
                <div class="form-group">
                    <label>المشروع</label>
                    <select name="project_id" required>
                        <option value="">اختر المشروع</option>
                    </select>
                </div>
                <div class="form-group">
                    <label>التاريخ</label>
                    <input type="date" name="revenue_date" required>
                </div>
                <div class="form-group">
                    <label>المبلغ</label>
                    <input type="number" name="amount" step="0.01" required>
                </div>
                <div class="form-group">
                    <label>طريقة الدفع</label>
                    <select name="payment_method" required>
                        <option value="cash">نقدي</option>
                        <option value="bank">بنك</option>
                        <option value="transfer">حوالة</option>
                    </select>
                </div>
                <div class="form-group">
                    <label>الوصف</label>
                    <textarea name="description" rows="3"></textarea>
                </div>
                <button type="submit">إضافة الإيراد</button>
            </form>
        </div>
    </div>

    <script src="js/finances.js"></script>
</body>
</html>