let projects = [];

document.addEventListener('DOMContentLoaded', function() {
  loadProjects();

  // إضافة مستمعي الأحداث
  document.getElementById('statusFilter').addEventListener('change', filterProjects);
  document.getElementById('searchProject').addEventListener('input', filterProjects);
  document.getElementById('addProjectForm').addEventListener('submit', handleAddProject);
});

// تحميل المشاريع
function loadProjects() {
  fetch('api/projects/get_all.php')
    .then(response => response.json())
    .then(data => {
      projects = data;
      renderProjects(projects);
    })
    .catch(error => console.error('Error:', error));
}

// عرض المشاريع
function renderProjects(projectsToRender) {
  const grid = document.getElementById('projectsGrid');
  grid.innerHTML = '';

  projectsToRender.forEach(project => {
    const card = createProjectCard(project);
    grid.appendChild(card);
  });
}

// إنشاء بطاقة مشروع
function createProjectCard(project) {
  const card = document.createElement('div');
  card.className = 'project-card';

  card.innerHTML = `
        <h3>${project.project_name}</h3>
        <div class="project-info">
            <p>تاريخ البداية: ${formatDate(project.start_date)}</p>
            <p>تاريخ النهاية المتوقع: ${formatDate(project.expected_end_date)}</p>
            <p>الحالة: ${getStatusInArabic(project.status)}</p>
        </div>
        <div class="progress-bar">
            <div class="progress-bar-fill" style="width: ${project.progress_percentage}%"></div>
        </div>
        <p>نسبة الإنجاز: ${project.progress_percentage}%</p>
        <div class="project-actions">
            <button class="edit-btn" onclick="editProject(${project.id})">تعديل</button>
            <button class="delete-btn" onclick="deleteProject(${project.id})">حذف</button>
        </div>
    `;

  return card;
}

// تصفية المشاريع
function filterProjects() {
  const statusFilter = document.getElementById('statusFilter').value;
  const searchText = document.getElementById('searchProject').value.toLowerCase();

  let filtered = projects;

  if (statusFilter) {
    filtered = filtered.filter(project => project.status === statusFilter);
  }

  if (searchText) {
    filtered = filtered.filter(project =>
      project.project_name.toLowerCase().includes(searchText)
    );
  }

  renderProjects(filtered);
}

// إضافة مشروع جديد
async function handleAddProject(e) {
  e.preventDefault();

  const formData = new FormData(e.target);
  const projectData = {
    project_name: formData.get('projectName'),
    start_date: formData.get('startDate'),
    expected_end_date: formData.get('expectedEndDate'),
    status: formData.get('projectStatus')
  };

  try {
    const response = await fetch('api/projects/add.php', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify(projectData)
    });

    if (response.ok) {
      closeAddProjectModal();
      loadProjects();
      showNotification('تم إضافة المشروع بنجاح');
    } else {
      throw new Error('فشل في إضافة المشروع');
    }
  } catch (error) {
    showNotification(error.message, 'error');
  }
}

// تعديل مشروع
function editProject(projectId) {
  // سيتم تنفيذه لاحقاً
}

// حذف مشروع
async function deleteProject(projectId) {
  if (confirm('هل أنت متأكد من حذف هذا المشروع؟')) {
    try {
      const response = await fetch(`api/projects/delete.php?id=${projectId}`, {
        method: 'DELETE'
      });

      if (response.ok) {
        loadProjects();
        showNotification('تم حذف المشروع بنجاح');
      } else {
        throw new Error('فشل في حذف المشروع');
      }
    } catch (error) {
      showNotification(error.message, 'error');
    }
  }
}

// وظائف مساعدة
function formatDate(dateString) {
  return new Date(dateString).toLocaleDateString('ar-SA');
}

function getStatusInArabic(status) {
  const statusMap = {
    'active': 'نشط',
    'completed': 'مكتمل',
    'on_hold': 'متوقف'
  };
  return statusMap[status] || status;
}

// إدارة النافذة المنبثقة
function showAddProjectModal() {
  document.getElementById('addProjectModal').style.display = 'block';
}

function closeAddProjectModal() {
  document.getElementById('addProjectModal').style.display = 'none';
  document.getElementById('addProjectForm').reset();
}

// إظهار الإشعارات
function showNotification(message, type = 'success') {
  const notification = document.createElement('div');
  notification.className = `notification ${type}`;
  notification.textContent = message;

  document.body.appendChild(notification);

  setTimeout(() => {
    notification.remove();
  }, 3000);
}