<?php
session_start();
require_once 'config.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}
?>

<!DOCTYPE html>
<html dir="rtl" lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>التقارير - نظام المقاولات</title>
    <link rel="stylesheet" href="css/style.css">
    <link rel="stylesheet" href="css/reports.css">
    <!-- إضافة مكتبة Chart.js للرسوم البيانية -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>
<body>
    <div class="dashboard-container">
        <?php include 'includes/sidebar.php'; ?>
        
        <main class="main-content">
            <div class="header">
                <h1>التقارير</h1>
            </div>

            <!-- أنواع التقارير -->
            <div class="reports-types">
                <button class="report-btn active" data-report="financial">التقارير المالية</button>
                <button class="report-btn" data-report="projects">تقارير المشاريع</button>
                <button class="report-btn" data-report="workers">تقارير العمال</button>
            </div>

            <!-- فلاتر التقارير -->
            <div class="report-filters">
                <div class="filter-group">
                    <label>الفترة:</label>
                    <select id="periodFilter">
                        <option value="today">اليوم</option>
                        <option value="week">هذا الأسبوع</option>
                        <option value="month">هذا الشهر</option>
                        <option value="year">هذا العام</option>
                        <option value="custom">فترة مخصصة</option>
                    </select>
                </div>
                
                <div class="custom-date-range" style="display: none;">
                    <div class="filter-group">
                        <label>من:</label>
                        <input type="date" id="startDate">
                    </div>
                    <div class="filter-group">
                        <label>إلى:</label>
                        <input type="date" id="endDate">
                    </div>
                </div>

                <div class="filter-group">
                    <label>المشروع:</label>
                    <select id="projectFilter">
                        <option value="">جميع المشاريع</option>
                    </select>
                </div>

                <button id="generateReport" class="generate-btn">إنشاء التقرير</button>
                <button id="printReport" class="print-btn">طباعة</button>
                <button id="exportExcel" class="export-btn">تصدير Excel</button>
            </div>

            <!-- محتوى التقارير -->
            <div class="report-content">
                <!-- التقارير المالية -->
                <div id="financial-report" class="report-section active">
                    <div class="summary-cards">
                        <div class="summary-card">
                            <h3>إجمالي الإيرادات</h3>
                            <p id="totalRevenues">0 ريال</p>
                        </div>
                        <div class="summary-card">
                            <h3>إجمالي المصروفات</h3>
                            <p id="totalExpenses">0 ريال</p>
                        </div>
                        <div class="summary-card">
                            <h3>صافي الربح</h3>
                            <p id="netProfit">0 ريال</p>
                        </div>
                        <div class="summary-card">
                            <h3>المصروفات المعلقة</h3>
                            <p id="pendingExpenses">0 ريال</p>
                        </div>
                    </div>

                    <div class="charts-container">
                        <div class="chart-wrapper">
                            <canvas id="revenueExpenseChart"></canvas>
                        </div>
                        <div class="chart-wrapper">
                            <canvas id="profitTrendChart"></canvas>
                        </div>
                    </div>

                    <div class="detailed-tables">
                        <div class="table-section">
                            <h3>تفاصيل الإيرادات</h3>
                            <table id="revenuesTable">
                                <thead>
                                    <tr>
                                        <th>التاريخ</th>
                                        <th>المشروع</th>
                                        <th>المبلغ</th>
                                        <th>طريقة الدفع</th>
                                    </tr>
                                </thead>
                                <tbody></tbody>
                            </table>
                        </div>
                        <div class="table-section">
                            <h3>تفاصيل المصروفات</h3>
                            <table id="expensesTable">
                                <thead>
                                    <tr>
                                        <th>التاريخ</th>
                                        <th>المشروع</th>
                                        <th>المبلغ</th>
                                        <th>النوع</th>
                                        <th>الحالة</th>
                                    </tr>
                                </thead>
                                <tbody></tbody>
                            </table>
                        </div>
                    </div>
                </div>

                <!-- تقارير المشاريع -->
                <div id="projects-report" class="report-section">
                    <div class="summary-cards">
                        <div class="summary-card">
                            <h3>إجمالي المشاريع</h3>
                            <p id="totalProjects">0</p>
                        </div>
                        <div class="summary-card">
                            <h3>المشاريع النشطة</h3>
                            <p id="activeProjects">0</p>
                        </div>
                        <div class="summary-card">
                            <h3>المشاريع المكتملة</h3>
                            <p id="completedProjects">0</p>
                        </div>
                        <div class="summary-card">
                            <h3>متوسط مدة المشروع</h3>
                            <p id="avgProjectDuration">0 يوم</p>
                        </div>
                    </div>

                    <div class="charts-container">
                        <div class="chart-wrapper">
                            <canvas id="projectStatusChart"></canvas>
                        </div>
                        <div class="chart-wrapper">
                            <canvas id="projectProgressChart"></canvas>
                        </div>
                    </div>

                    <div class="table-section">
                        <h3>تفاصيل المشاريع</h3>
                        <table id="projectsTable">
                            <thead>
                                <tr>
                                    <th>اسم المشروع</th>
                                    <th>تاريخ البداية</th>
                                    <th>تاريخ النهاية المتوقع</th>
                                    <th>نسبة الإنجاز</th>
                                    <th>الإيرادات</th>
                                    <th>المصروفات</th>
                                    <th>صافي الربح</th>
                                </tr>
                            </thead>
                            <tbody></tbody>
                        </table>
                    </div>
                </div>

                <!-- تقارير العمال -->
                <div id="workers-report" class="report-section">
                    <div class="summary-cards">
                        <div class="summary-card">
                            <h3>إجمالي العمال</h3>
                            <p id="totalWorkers">0</p>
                        </div>
                        <div class="summary-card">
                            <h3>العمال النشطين</h3>
                            <p id="activeWorkers">0</p>
                        </div>
                        <div class="summary-card">
                            <h3>إجمالي المستحقات</h3>
                            <p id="totalDues">0 ريال</p>
                        </div>
                        <div class="summary-card">
                            <h3>متوسط الأجر اليومي</h3>
                            <p id="avgDailyWage">0 ريال</p>
                        </div>
                    </div>

                    <div class="charts-container">
                        <div class="chart-wrapper">
                            <canvas id="workerAttendanceChart"></canvas>
                        </div>
                        <div class="chart-wrapper">
                            <canvas id="workerCostChart"></canvas>
                        </div>
                    </div>

                    <div class="table-section">
                        <h3>سجل العمال</h3>
                        <table id="workersTable">
                            <thead>
                                <tr>
                                    <th>اسم العامل</th>
                                    <th>الكود</th>
                                    <th>أيام العمل</th>
                                    <th>إجمالي الساعات</th>
                                    <th>المستحقات</th>
                                    <th>المدفوعات</th>
                                    <th>المتبقي</th>
                                </tr>
                            </thead>
                            <tbody></tbody>
                        </table>
                    </div>
                </div>
            </div>
        </main>
    </div>

    <script src="js/reports.js"></script>
</body>
</html>